[llvm-commits] [llvm] r139993 - /llvm/trunk/lib/Target/X86/X86ISelLowering.cpp

Craig Topper craig.topper at gmail.com
Sun Sep 18 01:03:58 PDT 2011


Author: ctopper
Date: Sun Sep 18 03:03:58 2011
New Revision: 139993

URL: http://llvm.org/viewvc/llvm-project?rev=139993&view=rev
Log:
Fix typo by changing Lower256IntVETCC to Lower256IntVSETCC.

Modified:
    llvm/trunk/lib/Target/X86/X86ISelLowering.cpp

Modified: llvm/trunk/lib/Target/X86/X86ISelLowering.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/X86/X86ISelLowering.cpp?rev=139993&r1=139992&r2=139993&view=diff
==============================================================================
--- llvm/trunk/lib/Target/X86/X86ISelLowering.cpp (original)
+++ llvm/trunk/lib/Target/X86/X86ISelLowering.cpp Sun Sep 18 03:03:58 2011
@@ -8414,9 +8414,9 @@
                      DAG.getConstant(X86CC, MVT::i8), EFLAGS);
 }
 
 // Lower256IntVETCC - Break a VSETCC 256-bit integer VSETCC into two new 128
 // ones, and then concatenate the result back.
-static SDValue Lower256IntVETCC(SDValue Op, SelectionDAG &DAG) {
+static SDValue Lower256IntVSETCC(SDValue Op, SelectionDAG &DAG) {
   EVT VT = Op.getValueType();
 
   assert(VT.getSizeInBits() == 256 && Op.getOpcode() == ISD::SETCC &&
@@ -8520,7 +8520,7 @@
 
   // Break 256-bit integer vector compare into smaller ones.
   if (!isFP && VT.getSizeInBits() == 256)
-    return Lower256IntVETCC(Op, DAG);
+    return Lower256IntVSETCC(Op, DAG);
 
   // We are handling one of the integer comparisons here.  Since SSE only has
   // GT and EQ comparisons for integer, swapping operands and multiple
@@ -8414,9 +8414,9 @@
 }
 
-// Lower256IntVETCC - Break a VSETCC 256-bit integer VSETCC into two new 128
+// Lower256IntVSETCC - Break a VSETCC 256-bit integer VSETCC into two new 128
 // ones, and then concatenate the result back.





More information about the llvm-commits mailing list